//*************************************************************************
/*
    Copyright (c) 2005. Pandora Products. All Rights Reserved.
*/
//*************************************************************************
/*
*  Module Name:         LINSERIAL		- Serial Support on a Linux system
*
*  Description:         This will list,open,setup and close serial ports
*						on Linux
*
*  Author:              Jim Schimpf
*
*  Revision History:	1 Dec 2005 Initial version
*
*		USER-API	PORT_LIST *ListPorts()				- NOP here
*					void ListPortsFree( PORT_LIST *l);
*					PORT_HANDLE *OpenPort( PORT_LIST *e,
*											int baud,
*											int stop,
*											int parity);
*					ClosePort( PORT_HANDLE *h );
*					int StatPort( PORT_HANDLE *h );
*					int WritePort( char *data,int size,PORT_HANDLE *h );
*					int ReadPort( char *data,int size,PORT_HANDLE *h );
*/
//************************************************************************

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include <ctype.h>
#include <sys/ioctl.h>
#include <errno.h>
#include <paths.h>
#include <termios.h>
#include <sysexits.h>
#include <sys/param.h>
#include <sys/select.h>
#include <sys/time.h>
#include <time.h>
#include "tgtypes.h"

#ifndef LINSERIAL_H
#define LINSERIAL_H	1

#pragma mark -- Structures --

typedef struct sdummy {
						struct sdummy *next;
						char *path;				// Path of port
						char *name;				// Just the name part of the port
					} PORT_LIST;
					
#define NEW_PORT_LIST		((PORT_LIST *)MEMALLOC(sizeof(PORT_LIST)))

// Parity & Stop bit defs

typedef enum {
				SER_PARITY_NONE,
				SER_PARITY_EVEN,
				SER_PARITY_ODD
			} SER_PORT_PARITY;
			
typedef enum {
				SER_STOP_ONE,
				SER_STOP_TWO
			} SER_PORT_STOP;

typedef struct {
					char *path;
					char *name;
					
					// PORT DATA
					struct termios orig;	// Original values
					struct termios run;		// Run values
					int fd;					// Port descriptor
					
				} PORT_HANDLE;
				
#define NEW_PORT_HANDLE		((PORT_HANDLE *)MEMALLOC(sizeof(PORT_HANDLE)))

#pragma mark -- API --

// **** PORT DETERMINATION ****
PORT_LIST *ListPorts(void);
void FreePorts(PORT_LIST *base );

// **** PORT OPEN/CLOSE

PORT_HANDLE *OpenPort( int psn,
						PORT_LIST *p,
						int baud,
						SER_PORT_STOP stop,
						SER_PORT_PARITY parity);
void ClosePort( PORT_HANDLE *h );

// **** PORT I/O

int StatPort( PORT_HANDLE *h );
int WritePort( char *buffer,int size,PORT_HANDLE *h);
int ReadPort( char *buffer, int size,PORT_HANDLE *h );

// *** PORT MISC

int CTSPort( PORT_HANDLE *h );				// Read CTS
void DTRPort( int flag,PORT_HANDLE *h);		// Set DTR

#endif
