-------------------------------------------------------------------------------
-- Copyright (C) 2004, Tollgrade Communications, Inc.  All Rights Reserved.
-------------------------------------------------------------------------------
--@@@@@@@ @@@@@@@  @@     @@     @@@@@@@@ @@@@@@@@   @@@@   @@@@@@@  @@@@@@@
--  @@   @@@   @@@ @@     @@    @@@       @@    @@  @@  @@  @@   @@@ @@
--  @@   @@     @@ @@     @@    @@@  @@@@ @@@@@@@  @@@  @@@ @@    @@ @@@@@@
--  @@   @@     @@ @@     @@    @@@    @@ @@   @@@ @@@@@@@@ @@    @@ @@
--  @@   @@@   @@@ @@     @@     @@@@  @@ @@    @@ @@    @@ @@   @@@ @@
--  @@    @@@@@@@  @@@@@@ @@@@@@@  @@@@@@ @@    @@ @@    @@ @@@@@@@  @@@@@@@
-------------------------------------------------------------------------------
--
-- Module Name: termtest.lua
--
-- Description: This a LUA (5.0) support file for TERMS a simple terminal
--              server.  This server will call various lua functions on
--              changes of state.
--
--  On Startup up       ON_START()      - Function called as TERMS starts
--  On TCP/IP connect   ON_CONN()       - Called when TCP/IP connection is up
--  On TCP/IP drop      ON_DROP()       - Called when TCP/IP connection drops
--  On CTS change       ON_CTS()        - Called when CTS serial line changes
--  Periodic            ON_PERIODIC()   - Called every second while TERMS runs
--
-- Extensions for TERMS support
--
--  timer       tstart()                - Create a timer object
--              tclose(t)               - Delete timer object
--              tdone(t,period)         - Is period over (in ms)
--              tstart(t)               - Reset timer to 0
--
--  ser         swrite(data)            - Write data to serial port
--              sread( size )           - Read size bytes from serial port
--              sstat()                 - Return # bytes on serial port
--              sgetstate()             - Return state of CTS
--              ssetstate()             - Set DTR
--
--  net         swrite(data)            - Write data to network port
--              sread(size)             - Read size bytes from network port
--              sstat()                 - Return # bytes on network port
--              drop()                  - Drop network connection
--              cstat()                 - Status of network connection 
--
--  23-May-2004  Initial Version
--  25-May-2004  Updated and corrections
--
-------------------------------------------------------------------------------


--------------------------------------------------------------------
--
-- function ON_START()    - Run at TERMS startup
--
-- INPUT:   NONE
--
-- OUTPUT:  NONE
--
---------------------------------------------------------------------
function ON_START()
    local out
    
    print()
    print("-------------------------------------")
    out = string.format("**** TERMS SERVER UP *****");
    print(out)
    out = string.format("[%s]\n[%s]",
                            "Lua 5.0.2",
                            "R. Ierusalimschy, L. H. de Figueiredo & W. Celes")
    print(out)
    print("-------------------------------------")
    print()
end
    

--------------------------------------------------------------------
--
-- function ON_CONN()    - Run at network connection startup
--
-- INPUT:   NONE
--
-- OUTPUT:  NONE
--          This version will toggle DTR on connection then
--          send a crcr to get a password prompt
--
---------------------------------------------------------------------
function ON_CONN()
	local out
	local t
	local count
		
	out = string.format("Connection UP\n")
	print(out)
	net.swrite(out)
	
	-- Now Lower DTR hold for 2 seconds then raise
	
--	print("Togging DTR")
--	ser.ssetstate( 0 );
--	t = timer.topen()
--	if( t ~= nil )
--	then
--	   while( timer.tdone(t,2000) == nil )
--	   do
--	       out = nil
--	   end
	   
--	   timer.tclose(t);
--    end
    
    print("DTR ASSERTED")
    ser.ssetstate( 1 )
    ser.swrite("\r\n")
	
end

--------------------------------------------------------------------
--
-- function ON_DROP()    - Run at network drop
--
-- INPUT:   NONE
--
-- OUTPUT:  NONE
--          This will lower DTR on exit which will cause the connected
--          unit to logout
--
---------------------------------------------------------------------
function ON_DROP()
    local out
    
	out = string.format("Connection DOWN")
	print(out)
	print("Lower DTR")
	ser.ssetstate( 0 );

end

function ON_CTS()
    local out
    local val
    
    val = ser.sgetstate()
    out = string.format("CTS = [%d]",val)
    print(out)
end

-- These globals used by ON_PERIODIC
count = 0
nettime = 0

--------------------------------------------------------------------
--
-- function ON_PERIODIC()    - Run every second
--
-- INPUT:   NONE
--
-- OUTPUT:  NONE
--          Print connection status and time
--
---------------------------------------------------------------------
function ON_PERIODIC()
    local out
    
    count = count + 1
    if( count > 5 )
    then
        if( net.cstat() )
        then
            out = string.format("Periodic Message [NET UP %d sec]",
                                    nettime)
            nettime = nettime + 5
        else
            out = string.format("Periodic Message")
            nettime = 0
        end
        
        print(out)
        count = 0
    end
end



