//*****************************************************************************
/*
    Module Name: SMC.H

    Description:    This is the task and API for Serial Multiplexed
					Communications.
					After the task is started then other tasks can open
					the API and use the communications.
                    
                    :<Size/Socket><Data><Cksum>
                    :				- Marks packet start
                    <Size/Socket>	- Bits 0/1 = Socket #
                                      Bits 7-2 = Size of message
                    <Data>			- 1-63 bytes of data
					<Cksum>			- Mod 256 cksum over the whole packet
    Notes:

    Revision History:

       26-Jan-2003	JS	Initial Version
       30-Jan-2003 	JS	Add in init call
        7-Feb-2003 	JS	Add in READ/WRITE calls
        1-Jul-2003	JS	Pass baud rate in on open
*/
//*****************************************************************************

#include "stdlib.h"
#include "tgtypes.h"

#ifndef SMC_H
#define SMC_H	1


#define SMC_HANDLE_VALID	'SMCH'

typedef struct smc_handle_dummy {
				TG_UINT32	valid;
                TG_HANDLE	env;		// Working env
				TG_HANDLE 	smc;
				// Put MQX handle here 
				TG_HANDLE 	std;
			} SMC_HANDLE;

#define NEW_SMC_HANDLE		(SMC_HANDLE *)MEMALLOC(sizeof(SMC_HANDLE))

/*****************************************************************************
					*** SMC API ***
*****************************************************************************/

// Protocol management functions
void *SMC_INIT_ENV(int port,int baud);
void SMC_PROTO_DRIVE( void *env );
void SMC_CLOSE_ENV( void *env );

// I/O API
SMC_HANDLE *SMC_COMOPEN(void *env,
                        int socket,
                        char *name,
                        int type,
                        char *baud);
                        
void		SMC_COMCLOSE( SMC_HANDLE *h );

int			SMC_FGETC( SMC_HANDLE *h );
void		SMC_FPUTC( int ch,SMC_HANDLE *h );

int			SMC_FWRITE( char *buffer,int size,int nelem,SMC_HANDLE *h );
int			SMC_FREAD( char *buffer,int size,int nelem,SMC_HANDLE *h );


#endif