//*****************************************************************************
/*
    Module Name: SMCPROTO.H

    Description:    This is the protocol layer for the Serial Mux System
                    The protocol is a full duplex exchange of unacknowledged
                    packets of the form:
                    
                    :<Size/Socket><Data><Cksum>
                    :				- Marks packet start
                    <Size/Socket>	- Bits 0/1 = Socket #
                                      Bits 7-2 = Size of message
                    <Data>			- 1-63 bytes of data
					<Cksum>			- Mod 256 cksum over the whole packet
    Notes:

    Revision History:

       26-Jan-2003	JS	Initial Version
       27-Jan-2003 	JS	Add handle grabber mutex
        3-Feb-2003	JS	Add a status checker
        1-Jul-2003	JS	Pass baud rate in on open
*/
//*****************************************************************************

#ifndef SMCPROTO_H
#define SMCPROTO_H	1

#include <stdlib.h>
#include <pthread.h>
#include <stdio.h>
#include <sys/time.h>
#include <ctype.h>
#include <stdio.h>
#include "tgtypes.h"
#include "CserialSup.h"

#define SMC_MAX_HANDLES		4
#define SMC_MAX_IBUF		4096
#define SMC_PROTO_HANDLE_VALID	'SMCH'

typedef struct smc_user_handle {

                    TG_UINT32 valid;
                    
					// Input data
					TG_BOOL	in_use;		// TRUE when open
					pthread_mutex_t		in_mutex;
					int socket;			// Socket # for this handle

					int head;			// Put in data here
					int tail;			// Take data out here
					int size;			// # bytes in buffer
					TG_BYTE	data[SMC_MAX_IBUF];
					
					// Output data
					
					int out_size;
					TG_BYTE output[SMC_MAX_IBUF];
					
					void *p;			// Pointer to main struct
                    					
				} SMC_PROTO_HANDLE;
		

#define SMC_PROTO_MAX_DATA	64
#define SMC_SOCKET_MASK		0x3
#define SMC_HEADER_CH		':'

typedef enum {
				SMC_HEADER,		// Search for header state
				SMC_CNTL,		// Get size/socket
				SMC_DATA,		// Get data
				SMC_CKSUM,		// Do checksum
			} SMC_STATE;
			
#define SMC_PROTO_VALID	'SMCP'

typedef struct smc_proto_dummy {
			TG_UINT32	valid;
			SMC_STATE	state;
			TG_UINT32	cksum;
			int			socket;
			int			data_size;
			int			data_ptr;
			TG_BYTE		data[SMC_PROTO_MAX_DATA];
			X_SPORT		*port;						// Data port
			
			// User support
			
			pthread_mutex_t	out_mutex;		// output MUTEX
			int out_count;
			int in_count;
			
			pthread_mutex_t	handle_mutex;	// Handle protection
			SMC_PROTO_HANDLE handles[SMC_MAX_HANDLES];
			
		} SMC_PROTO;
		
// PROTO API

SMC_PROTO *SMC_proto_init( int port,int baud );		// Management
void SMC_proto_drive( SMC_PROTO *p );
void SMC_close_env( SMC_PROTO *p );

int SMC_proto_write(TG_BYTE *buffer,int size,SMC_PROTO_HANDLE *h);	// I/O API
int SMC_proto_read(TG_BYTE *buffer,int size,SMC_PROTO_HANDLE *h);
int SMC_proto_status(SMC_PROTO_HANDLE *h);

#endif