//*************************************************************************
/*
    Copyright (c) 2004. Tollgrade Communications, Inc. All Rights Reserved.
*/
//*************************************************************************
/*
*  Module Name:         TERMS	- Terminal Server
*
*  Description:         This becomes a terminal server which
*						connects a TCP/IP port to a serial 
*						port
*
*  Author:              Jim Schimpf
*
*  Revision History:	19 May 2004 Initial version
*						23 May 2004 Add in LUA
*						 1 Dec 2005 Use common serial code
*
*  SYNTAX:	terms [-p <serial port #>] [-baud <baud rate>] [-tcp_p <TCP/IP Port #>] [-v]
*				-p	Serial port #	DEFAULT = 1
*				-baud Baud rate for serial port DEFAULT 38400
*				-tcp_p TCP Port # 	DEFAULT = 7000
*				NOTE: Selection of port # < 1024 requires ADMIN access
*				-v	Show version and information*
*
*	This program will run in 4 threads
*		Thread 0	- Main thread block till others finish
*		Thread 1	- TERMS engine
*
*		Thread 2	- Telnet receive Telnet port (block waiting for access)
*		Thread 3	- TERMS Receive telnet xmit
*
************************************************************************/

#ifndef TERMS_H
#define TERMS_H	1

#include <stdio.h>
#include <pthread.h>
#include <string.h>

#ifdef LINUX_VERSION
	#include "linserial.h"
#else
	#include "bsdserial.h"
#endif

#include "netcom.h"
#include "lstate.h"		// NOTE:This must be lstate.h not lua.h or the store of the ENV
						// in lua_State gets a bad struct reference

//**** LOCAL DEFINES
#define VERSION	"1.0"

typedef enum {
				TERMS_START,
				TERMS_CONN_WAIT,
				TERMS_CONN_RUN,
				TERMS_CONN_DROP,
				TERMS_EXIT
			} TERMS_STATE;

// I/O thread env

typedef struct {
		TERMS_STATE		state;			// Current state
		int				cts;			// Current CTS value
		int				dtr;			// Current DTR
		//pthread_t		t;				// Thread pointer
        //TG_BOOL			done;			// Quit when true
        NETCOM_CHANNEL *tcp_socket;		// TCP/IP socket
		PORT_HANDLE		*ser;			// Serial port
		
		// LUA Support 
		
		lua_State		*l;				// Lua state
    } MY_ENV;

// Engine thread env

typedef struct {
		pthread_t	t;
		void *env;
		TG_BOOL	done;
		} ENG_ENV;
		
#endif
