/***************************************************************************
*  Copyright (C) 1996,  Tollgrade Communications, Inc.  All Rights Reserved.
****************************************************************************
*
*  Module Name: TIMER.C
*
*  Description: Asynchronous timer functions
*
***************************************************************************/

/*************************************
*  C O M P I L E R    O P T I O N S
*************************************/


/********************************
*  I N C L U D E    F I L E S
********************************/

#include "tgtimer.h"


// ----------------------------------------------------------------------------

// Start timer, return time at which timer was started

void iTIMER_Start (TG_TIMER_STRUCT *pTimerInfo)
{
	struct timezone tzp;
	
    gettimeofday (pTimerInfo,&tzp);
}

// ----------------------------------------------------------------------------

// Determine if a given timer is expired yet.

// pTimerInfo = ptr to timer info set for this timer by TIMER_Start(),
// ui32TargetMilliSecs = # of milliseconds required elapsed to indicate finished.

// Any number of these "timers" may be running simultaneously,
// so long as each timer has its own timer structure.

// Example:

//      TG_TIMER_STRUCT     stTimer1;
//
//      TIMER_Start (& stTimer1);
//
//      // Wait one second
//      while (! TIMER_Finished (& stTimer1, 1000))
//      {
//      }


TG_BOOL iTIMER_Finished (TG_TIMER_STRUCT *pTimerInfo, TG_UINT32 ui32TargetMilliSecs)
{
    TG_TIMER_STRUCT stCurrentTime;
	struct timezone tzp;
    TG_UINT32      ui32ElapsedMilliSecs;


    gettimeofday (&stCurrentTime,&tzp);

    ui32ElapsedMilliSecs = iTIMER_GetElapsedMillisecs (pTimerInfo, &stCurrentTime);

    return (ui32ElapsedMilliSecs >= ui32TargetMilliSecs);
}


// ----------------------------------------------------------------------------

// Return the # of milliseconds from the 1st time to the 2nd time struct.

TG_UINT32 iTIMER_GetElapsedMillisecs (
                TG_TIMER_STRUCT *   pTimerInfo1,    // start time
                TG_TIMER_STRUCT *   pTimerInfo2)    // current or finished time
{
    TG_UINT32  ui32ElapsedSeconds;
    TG_UINT32  ui32ElapsedMillisecs;
    
    // Handle the edge cases
    
    if( pTimerInfo2 == NULL )
        return( 0 );					// Bail bad input
        
    if( pTimerInfo1 == NULL )
    {
        // Start from 0 case
        
        ui32ElapsedSeconds   = pTimerInfo2->tv_sec;
        ui32ElapsedMillisecs = pTimerInfo2->tv_usec;
    }
    else
    {
        // Start from base case
        ui32ElapsedSeconds   = pTimerInfo2->tv_sec - pTimerInfo1->tv_sec;
        ui32ElapsedMillisecs = pTimerInfo2->tv_usec - pTimerInfo1->tv_usec;
    }

    // Now do the calcs
    
    ui32ElapsedMillisecs += 1000000 * ui32ElapsedSeconds;
	ui32ElapsedMillisecs /= 1000;			// Note convert back to ms from usec
    return ui32ElapsedMillisecs;
}
